Welcome to hepstats’s documentation! — hepstats 0.2.1 documentation

# Welcome to hepstats’s documentation!

hepstats is a python library providing statistics tools and utilities for particles physics. It can be installed It can be installed with `pip` from PyPI.

Contents:

- Installation
- Quick start
  - modeling
  - hypotests

API Reference:

- hepstats
  - Submodules
    - hepstats.modeling module
      - Bayesian blocks
        - Bayesian Block implementation
    - hepstats.hypotests module
      - Parameters
      - Calculators
        - Asymptotic
        - Frequentist
      - Discovery test
      - Upper limit
      - Confidence interval
      - Hypotests objects
      - Toy utilities
    - hepstats.splot module
      - sWeights

# Indices and tables

- Index

- Module Index

- Search Page

# bibliography

BB_

  Dynamic Programming in Python: Bayesian Blocks, howpublished = http://jakevdp.github.io/blog/2012/09/12/dynamic-programming-in-python/. Accessed: 2020-11-03.

PLD05

  Muriel Pivk and Francois R. Le Diberder. SPlot: A Statistical tool to unfold data distributions. Nucl. Instrum. Meth., A555:356–369, 2005. arXiv:physics/0402083, doi:10.1016/j.nima.2005.08.106.

PBS17

  Brian Pollack, Saptaparna Bhattacharya, and Michael Schmitt. Bayesian Block Histogramming for High Energy Physics. 2017. arXiv:1708.00810.

SNJC13

  Jeffrey D. Scargle, Jay P. Norris, Brad Jackson, and James Chiang. Studies in astronomical time series analysis. vi. bayesian block representations. The Astrophysical Journal, 764(2):167, Feb 2013. URL: http://dx.doi.org/10.1088/0004-637X/764/2/167, doi:10.1088/0004-637x/764/2/167.

VCIG12

  Jacob VanderPlas, Andrew J. Connolly, Zeljko Ivezic, and Alex Gray. Introduction to astroml: machine learning for astrophysics. 2012 Conference on Intelligent Data Understanding, Oct 2012. URL: http://dx.doi.org/10.1109/CIDU.2012.6382200, doi:10.1109/cidu.2012.6382200.